@@ -21,7 +21,7 @@ import re
 
 __all__ = ['space','intset']
 
-bindings_version = (0, 21)
+bindings_version = (0, 22)
 
 space = _gecode.space
 intset = _gecode.intset
@@ -34,3 +34,32 @@ for x in dir(_gecode):
     if RE_CONSTANT.match(x):
         THIS[x] = getattr(_gecode, x)
         __all__.append(x)
+
+from types import ClassType, TypeType
+CLASSTYPES=(TypeType,ClassType)
+
+def inspector(name):
+    assert isinstance(name,(str,unicode))
+    def mk_inspector(fun):
+        if type(fun) in CLASSTYPES:
+            fun = fun()
+        if not callable(fun):
+            raise TypeError("expected a callable: %s" % fun)
+        fun.__inspector__ = name
+        return fun
+    return mk_inspector
+
+__all__.append('inspector')
+
+def textinspector(name):
+    assert isinstance(name,(str,unicode))
+    def mk_textinspector(fun):
+        if type(fun) in CLASSTYPES:
+            fun = fun()
+        if not callable(fun):
+            raise TypeError("expected a callable: %s" % fun)
+        fun.__textinspector__ = name
+        return fun
+    return mk_textinspector
+
+__all__.append('textinspector')
